<div data-role="page" data-theme="b" id="zim-iframe">
    <div data-role="header">
        <div class="ui-grid-b">
            <div class="ui-block-a">
                <a href="/iiab/" data-role="button" data-icon="home" data-mini="true" data-iconpos="notext" data-direction="reverse">Home</a>
            </div>
            <div class="ui-block-b">
                <h1 class="ui-title">Wikipedia</h1>
            </div>
            <div class="ui-block-c">
                <fieldset style="margin: 0px" data-role="controlgroup">
                    <label for="searchinput1">
                    </label>
                    <input name="" data-mini="true" id="wikisearch" placeholder="Search" value="" type="search">
                </fieldset>
            </div>
        </div>
    </div>
    <div data-role="content">
        <div class="iframe-wrap">
            <iframe class="wiki-iframe" frameborder="0" height="100%" width="100%" src="{{ url }}">
            </iframe>
        </div>
    </div>
</div>

