{#
:param record: book record
:param fields: list of tuples (header_name, record_key)
#}
{% from 'macros/_misc.html' import render_book_details, render_book_files %}

{% extends 'layouts/base_navsearch.html' %}

{% set page_title = _('Book Details') %}

{% block body %}
    {{ render_book_details(record, fields, 'table') }}
    {{ render_book_files(record, fields, 'table') }}
{% endblock %}
