<footer class="footer">
    <div class="container">
        <ul class="footer-links">
            <li>{% trans %}Internet in a Box{% endtrans %}</li>
            <li class="muted">&middot;</li>
            <li>{% trans %}The World's Free Information at your Fingertips{% endtrans %}</li>
        </ul>
    </div>
</footer>
