<div data-role="page" data-theme="b" id="wikipedia-languages">
    <div data-role="header">
        <a href="/iiab/" data-icon="home" data-iconpos="notext" data-direction="reverse">Home</a>
        <h1>Wikipedia</h1>
    </div>
    <div data-role="content">
        <ul data-role="listview" data-divider-theme="b" data-inset="true">
            {% for language in languages %}
            <li data-role="list-divider" data-theme="c">
                {{ language['languageEnglish'] }}
            </li>
            {% for book in language['books'] %}
            <li data-theme="c">
            <a href="{{ kiwix_url + '/' + book.get('humanReadableId') + '/' }}" data-transition="slide" data-ajax="{{ 'true' if ajax else 'false' }}">
                <h3>{{ book.get('title') }}</h3>
                {% if 'description' in book %}
                <p style="white-space: normal;" class="float-left">{{ book.get('description') }}</p>
                {% endif %}
                <p class="float-right">{{ book['articleCountString'] }} Articles</p>
            </a>
            </li>
            {% endfor %}
            {% endfor %}
        </ul>
    </div>
</div>

